# -*- coding: utf-8 -*-

from django.utils.translation import ugettext as _
from django.contrib import admin

from image_cropping import ImageCroppingMixin

from jmb.jadmin import JumboModelAdmin

from . import models


log_fieldset = (
    (_('logs admin'), {
        'fields': (
            'creator', 'date_create',
            'last_modifier', 'date_last_modify',
        ),
        'classes': ('collapse',)
    })
)
ordering_fieldset = (
    (_('ordering admin'), {
        'fields': ('ordering',),
        'classes': ('collapse',)
    })
)


class GoalAdmin(ImageCroppingMixin, JumboModelAdmin):
    advanced_search_fields = (
        ('name__icontains',),
        ('owner__username__icontains',),
        ('owner__email__icontains',),
        ('contest',),
    )
    fieldsets = (
        log_fieldset, ordering_fieldset,
        (_('main'), {
            'fields': (
                ('owner', 'contest',),
                ('name', 'slug',),
                'description',
                'value',
                'photo',
                'photo_small',
            )
        }),
    )
    list_display = (
        'get_edit_icon', 'ordering', 'status', 'owner', 'contest', 'name', 'slug'
    )
    prepopulated_fields = {"slug": ("name",)}
    readonly_fields = ('owner', 'contest',)

    def has_add_permission(self, request):
        # non è possibile creare un nuovo goal da admin
        return False


class ContestAdmin(JumboModelAdmin):
    fieldsets = (
        log_fieldset, ordering_fieldset,
        (_('main'), {
            'fields': (
                ('name', 'slug',),
                'description',
            )
        }),
    )
    list_display = (
        'get_edit_icon', 'ordering', 'status', 'name', 'slug'
    )
    prepopulated_fields = {"slug": ("name",)}

admin.site.register(models.Goal, GoalAdmin)
admin.site.register(models.Contest, ContestAdmin)
