# -*- coding: utf-8 -*-
from django.db import models
from django.utils.encoding import python_2_unicode_compatible
from django.utils.translation import ugettext as _

from cms.models.pluginmodel import CMSPlugin

from jmb.core.db.cmsmodels import StatusModel

from acomea.contest_g5.models import Contest


@python_2_unicode_compatible
class ContestPluginSettings(CMSPlugin, StatusModel):
    contest = models.ForeignKey(
        Contest,
        verbose_name=_('contest')
    )
    watermark = models.ImageField(
        upload_to='contest_g5/watermark/',
        verbose_name=_('watermark'),
    )
    position_x = models.IntegerField(
        default='-10',
        verbose_name=_('position X in px'),
        help_text=_('positive: from left - negative: from right')
    )
    position_y = models.IntegerField(
        default='-10',
        verbose_name=_('position Y in px'),
        help_text=_('positive: from top - negative: from bottom')
    )
    opacity = models.DecimalField(
        max_digits=2,
        decimal_places=2,
        default=.50,
        verbose_name=_('opacity'),
        help_text=_('range between 0.01 to 0.99'),
    )

    def __str__(self):
        return 'Contest: {}'.format(self.contest.name)

    class Meta:
        app_label = "contest_g5"
