# -*- coding: utf-8 -*-

from django.utils.translation import ugettext as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from .forms import GoalForm
from .models import ContestPluginSettings


class GoalPlugin(CMSPluginBase):
    name = _("Contest")
    model = ContestPluginSettings
    module = _("AcomeA Contest Gimme5")
    admin_preview = False
    render_template = 'contest_g5/cms_plugins/empty.html'

    def render(self, context, instance, placeholder):
        request = context['request']
        user = request.user
        goal = None
        goal_form = None

        if user.is_anonymous():
            return context

        if instance.status is False:
            return context

        if request.method == 'GET':
            goals = user.goals.filter(contest=instance.contest)
            if goals:
                goal = goals[0]
                self.render_template = 'contest_g5/cms_plugins/goal_detail.html'
            else:
                goal_form = GoalForm()
                self.render_template = 'contest_g5/cms_plugins/goal_form.html'

        if (
            request.method == 'POST' and
            'contest_g5_goal_{}'.format(instance.id) in request.POST
        ):
            goal_form = GoalForm(request.POST, request.FILES)
            if goal_form.is_valid():
                goal = goal_form.save(user=user, instance=instance)
                self.render_template = 'contest_g5/cms_plugins/goal_detail.html'
            else:
                self.render_template = 'contest_g5/cms_plugins/goal_form.html'

        context.update({
            'instance': instance,
            'placeholder': placeholder,
            'goal': goal,
            'goal_form': goal_form
        })
        return context
plugin_pool.register_plugin(GoalPlugin)
