# coding: utf-8

from __future__ import unicode_literals

import os

from django.conf import settings
from django.contrib.auth.models import User
from django.db import models
from django.utils.encoding import python_2_unicode_compatible
from django.utils.translation import ugettext_lazy as _

from easy_thumbnails.files import get_thumbnailer
from image_cropping.fields import ImageRatioField
from imagekit.models import ProcessedImageField
from pilkit.processors import ResizeToFit

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel

from .utils import get_image


def get_upload_photo_path(instance, filename):
    media_dir = instance.creator.username[0:3]
    ext = filename.split('.')[-1]
    filename = '{}.{}'.format(instance.slug, ext)
    return os.path.join(u"goal", u"photos", u"{0}".format(media_dir), filename)


@python_2_unicode_compatible
class Contest(DateModel, UserModel, StatusModel, OrderedModel):
    name = models.CharField(
        max_length=255,
        verbose_name=_('name'),
    )
    slug = models.SlugField(
        max_length=255,
        verbose_name=_('slug'),
        unique=True,
    )
    description = models.TextField(
        blank=True,
        verbose_name=_('description'),
    )

    class Meta(object):
        verbose_name = _('Contest')
        verbose_name_plural = _('Contests')
        ordering = ("ordering", "name",)

    def __str__(self):
        return self.name


@python_2_unicode_compatible
class Goal(DateModel, UserModel, StatusModel, OrderedModel):
    owner = models.ForeignKey(
        User,
        related_name='goals',
        verbose_name=_('owner'),
    )
    contest = models.ForeignKey(
        Contest,
        related_name='goals',
        verbose_name=_('contest'),
    )
    name = models.CharField(
        max_length=255,
        verbose_name=_('name'),
    )
    slug = models.SlugField(
        max_length=255,
        verbose_name=_('slug'),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_('description'),
    )
    value = models.DecimalField(
        max_digits=8,
        decimal_places=2,
        verbose_name=_('value'),
    )
    photo = ProcessedImageField(
        upload_to=get_upload_photo_path,
        verbose_name=_('photo'),
        processors=[ResizeToFit(width=800)],
        format='JPEG',
        options={'quality': 60}
    )
    photo_small = ImageRatioField(
        'photo', '80x80',
        verbose_name=_("small photo")
    )

    class Meta(object):
        verbose_name = _('Goal')
        verbose_name_plural = _('Goals')
        ordering = ("ordering", "name",)
        unique_together = ('owner', 'contest',)

    def __str__(self):
        return self.name

    def get_photo_small(self):
        if self.photo:
            return get_thumbnailer(
                self.photo
            ).get_thumbnail({
                'size': (80, 80),
                'box': self.photo_small,
                'crop': True,
                'detail': True,
            }).url
        else:
            return settings.STATIC_URL + "contest_g5/img/product-small.jpg"

    def set_photo_gimme5(self, watermark_path, position_x=10, position_y=10, opacity=0.5):
        image = get_image(self.photo.path, watermark_path, (position_x, position_y), opacity)
        image.save(self.photo.path)


# import cms stuffs
if settings.CMS_ENABLED:
    import acomea.contest_g5.cms.plugins
    import acomea.contest_g5.cms.app
